package com.hand.app.zhongDengWang.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.hand.app.zhongDengWang.service.IZdwWsRequestsService;
import com.hand.app.zhongDengWang.dto.ZdwLoginTokenInterface;
import com.hand.app.zhongDengWang.dto.FndZhongDengLines;
import com.hand.app.zhongDengWang.dto.FndZhongDengBatch;
import com.hand.app.zhongDengWang.dto.HlsWsRequests;
import com.hand.app.zhongDengWang.service.IZdwWsRequestsService;
import com.hand.app.zhongDengWang.mapper.HlsWsRequestsMapper;
import com.hand.app.zhongDengWang.service.IFndZhongDengLinesService;
import com.hand.app.zhongDengWang.mapper.ZdwLoginTokenInterfaceMapper;
import com.hand.app.zhongDengWang.mapper.FndZhongDengLinesMapper;
import com.hand.app.zhongDengWang.mapper.FndZhongDengBatchMapper;
import com.hand.app.zhongDengWang.utils.ClientUtils;
import com.hand.app.zhongDengWang.ws.amend.WSAmendRegisterService;
import com.hand.app.zhongDengWang.ws.amend.WSAmendRegisterServiceService;
import com.hand.app.zhongDengWang.ws.extend.WSExtendRegisterService;
import com.hand.app.zhongDengWang.ws.extend.WSExtendRegisterServiceService;
import com.hand.app.zhongDengWang.ws.init.WSInitRegisterService;
import com.hand.app.zhongDengWang.ws.init.WSInitRegisterServiceService;
import com.hand.app.zhongDengWang.ws.login.WSLoginService;
import com.hand.app.zhongDengWang.ws.login.WSLoginServiceService;
import com.hand.app.zhongDengWang.dto.FndAtmAttachmentDto;
import com.hand.app.zhongDengWang.mapper.FndAtmAttachmentMapper;
import com.hand.app.zhongDengWang.ws.terminate.WSTerminateRegisterService;
import com.hand.app.zhongDengWang.ws.terminate.WSTerminateRegisterServiceService;
import com.hand.hap.core.IRequest;
import com.hand.hap.lock.components.DatabaseLockProvider;
import com.hand.hap.system.dto.DTOStatus;
import com.rfp.sm.utils.SM2Utils;
import org.json.XML;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.util.*;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

@Service
public class ZdwWsRequestsServiceImpl implements IZdwWsRequestsService {

    @Autowired
    ZdwLoginTokenInterfaceMapper zdwLoginTokenInterfaceMapper;
    @Autowired
    FndZhongDengLinesMapper fndZhongDengLinesMapper;
    @Autowired
    IFndZhongDengLinesService fndZhongDengLinesService;
    @Autowired
    IZdwWsRequestsService zdwWsRequestsService;
    @Autowired
    HlsWsRequestsMapper hlsWsRequestsMapper;
    @Autowired
    FndAtmAttachmentMapper fndAtmAttachmentMapper;
    @Autowired
    FndZhongDengBatchMapper fndZhongDengBatchMapper;
    @Autowired
    private DatabaseLockProvider databaseLockProvider;

    /**
     * Use private final lock objects to synchronize classes that may interact with untrusted code
     */
    private final Object lock = new Object();


    @Value("${zdw.login.clientKey}")
    private String clientKey;
    @Value("${zdw.login.userName}")
    private String userName;
    @Value("${zdw.login.password}")
    private String userPassword;
    @Value("${zdw.login.authCode}")
    private String platformAuthCode;

    private String loginToken;

    /**
     * 加密公钥 String clientKey
     * 用户名 String userName
     * 密码  String userPassword
     * 平台授权码 String platformAuthCode
     **/
    public static String clintLogin(String clientKey, String userName, String userPassword, String platformAuthCode) {
        String returnMsg = "";

        try {
            /*SM2算法加密*/
            userName = SM2Utils.encryptByKeyStr(userName, clientKey);
            userPassword = SM2Utils.encryptByKeyStr(userPassword, clientKey);
            platformAuthCode = SM2Utils.encryptByKeyStr(platformAuthCode, clientKey);
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        WSLoginServiceService service = new WSLoginServiceService();
        WSLoginService login = service.getWSLoginServicePort();
        try {
            byte[] returns = login.login(userName.getBytes(), userPassword.getBytes(), platformAuthCode.getBytes());
            returnMsg = new String(returns);
        } catch (Exception e) {
            e.printStackTrace();
            returnMsg = "LoginError";
        }
        System.out.println("token=" + returnMsg);
        return returnMsg;
    }

    private String getRegisterToken() {

        //获取token，后台设置每25分钟重置一次token
        ZdwLoginTokenInterface zdwLoginTokenInterface = new ZdwLoginTokenInterface();
        zdwLoginTokenInterface.setEnableFlag("Y");
        zdwLoginTokenInterface = zdwLoginTokenInterfaceMapper.selectOne(zdwLoginTokenInterface);

        String assesstoken = "";

        if (Objects.isNull(zdwLoginTokenInterface)) {
//            assesstoken = clintLogin(clientKey, userName, userPassword, platformAuthCode);
            assesstoken = "cs11111111";
            if (!assesstoken.contains("Error")) {
                zdwLoginTokenInterfaceMapper.updateToken(assesstoken);
            }
        } else {
            assesstoken = zdwLoginTokenInterface.getToken();
        }

        return assesstoken;
    }


    private HlsWsRequests createRequestLog(String wsdlUrl, String requestClob, Long pkValue) {
        HlsWsRequests hlsWsRequests = new HlsWsRequests();
        hlsWsRequests.setRequestDate(new Date());
        hlsWsRequests.setRequestWsdlUrl(wsdlUrl);
        hlsWsRequests.setFunctionName("INIT_REGISTER");
        hlsWsRequests.setRequestClob(requestClob);
        hlsWsRequests.setStatusDate(new Date());
        hlsWsRequests.setParameterType("XML");
        hlsWsRequests.setPkValue(pkValue);

        hlsWsRequestsMapper.insertSelective(hlsWsRequests);
        return hlsWsRequests;
    }

    /**
     * 设置错误信息
     * @param resultJson 返回给前端的结果集
     * @param hlsWsRequests 储存给数据库的请求体
     * @param e 异常
     */
    public void setErrData(JSONObject resultJson, HlsWsRequests hlsWsRequests, Exception e){
        resultJson.put("code", "-1");
        resultJson.put("info", e.getMessage());
        hlsWsRequests.setReturnStatus("E");
        hlsWsRequests.setResponsedDate(new Date());
    }

    /**
     * 设置返回信息
     * @param resultJson 返回给前端的结果集
     * @param hlsWsRequests 储存给数据库的请求体
     * @param resData 返回字符串
     */
    public void setResData(JSONObject resultJson, HlsWsRequests hlsWsRequests, String resData){
        resultJson.put("code", "0");
        resultJson.put("info", resData);
        hlsWsRequests.setReturnStatus("S");
        hlsWsRequests.setResponseClob(resData);
    }

    public JSONObject registerInit(String registerTypeBz, String platformAuthCode, String loginToken, String xmlFileName, String xmlFileContent, Long lineId) {
        JSONObject resultJson = new JSONObject();
        String encryXmlFileContent = "";
        String encryLoginToken = "";
        String attachmentZipPath = "";
        String encryPlatformAuthCode = "";
        HlsWsRequests hlsWsRequests = new HlsWsRequests();
        try {
            /*SM2算法加密*/
            encryLoginToken = SM2Utils.encryptByKeyStr(loginToken, clientKey);
            encryXmlFileContent = SM2Utils.encryptByKeyStr(xmlFileContent, clientKey);
            encryPlatformAuthCode = SM2Utils.encryptByKeyStr(platformAuthCode, clientKey);

//          WSInitRegisterServiceService service = new WSInitRegisterServiceService();
//          WSInitRegisterService reg = service.getWSInitRegisterServicePort();

            /*插入接口日志表*/
//          hlsWsRequests = createRequestLog(service.getWSDLDocumentLocation().toString(), xmlFileContent, lineId);
            hlsWsRequests = createRequestLog("https://ws.zhongdengwang.org.cn/mfrs_ws_test/services/InitRegisterService?wsdl", xmlFileContent, lineId);
//          byte[] returns = reg.initRegister(registerTypeBz.getBytes(), encryPlatformAuthCode.getBytes(), encryLoginToken.getBytes(), xmlFileName.getBytes(), encryXmlFileContent.getBytes(), ClientUtils.getAttachmentZip(attachmentZipPath));
            byte[] returns = "<feedback>\n<registertype>LR</registertype>\n<registerresult>001</registerresult>\n<registernumber>I0000001</registernumber>\n<authorizationcode>A0000001</authorizationcode>\n<errors>\n<error>RegInfoError:100_001</error>\n</errors>\n</feedback>\n".getBytes();

            setResData(resultJson, hlsWsRequests, new String(returns));

            System.out.println("dddd" + new String(returns));
        } catch (Exception e) {
            e.printStackTrace();
            setErrData(resultJson, hlsWsRequests, e);
        }

        hlsWsRequestsMapper.updateByPrimaryKeySelective(hlsWsRequests);
        return resultJson;
    }

    public JSONObject registerAmend(String platformAuthCode, String loginToken, String xmlFileContent, String attachmentZipPath, FndZhongDengLines line, FndAtmAttachmentDto attachmentDto){
        JSONObject resultJson = new JSONObject();
        HlsWsRequests hlsWsRequests = new HlsWsRequests();

        try {
            /*SM2算法加密*/
            String encryLoginToken = SM2Utils.encryptByKeyStr(loginToken, clientKey);
            String encryXmlFileContent = SM2Utils.encryptByKeyStr(xmlFileContent, clientKey);
            String encryPlatformAuthCode = SM2Utils.encryptByKeyStr(platformAuthCode, clientKey);
            String encryAuthorizationCode = SM2Utils.encryptByKeyStr(line.getAuthorizationCode(), clientKey);
            String encryRegisterCode = SM2Utils.encryptByKeyStr(line.getRegisterNumber(), clientKey);

            //搭建服务
            WSAmendRegisterServiceService service = new WSAmendRegisterServiceService();
            WSAmendRegisterService amend = service.getWSAmendRegisterServicePort();

            //插入接口日志表
            hlsWsRequests = createRequestLog("https://ws.zhongdengwang.org.cn/mfrs_ws_test/services/AmendRegisterService?wsdl", xmlFileContent, line.getLineId());

            //获取数据
            byte[] resBytes = amend.amendRegister(line.getTypebz().getBytes(), encryPlatformAuthCode.getBytes(),
                    encryLoginToken.getBytes(), encryRegisterCode.getBytes(), encryAuthorizationCode.getBytes(),
                    attachmentDto.getFileName().getBytes(), encryXmlFileContent.getBytes(),
                    ClientUtils.getAttachmentZip(attachmentZipPath));

            String resData = new String(resBytes);
            setResData(resultJson, hlsWsRequests, resData);

        } catch (Exception e) {
            e.printStackTrace();
            setErrData(resultJson, hlsWsRequests, e);
        }

        //返回结果 给数据库和前端
        hlsWsRequestsMapper.updateByPrimaryKeySelective(hlsWsRequests);
        return resultJson;
    }

    public JSONObject registerExtend(String platformAuthCode, String loginToken, String xmlFileContent, String attachmentZipPath, FndZhongDengLines line, FndAtmAttachmentDto attachmentDto){
        JSONObject resultJson = new JSONObject();
        HlsWsRequests hlsWsRequests = new HlsWsRequests();

        try {
            /*SM2算法加密*/
            String encryLoginToken = SM2Utils.encryptByKeyStr(loginToken, clientKey);
            String encryXmlFileContent = SM2Utils.encryptByKeyStr(xmlFileContent, clientKey);
            String encryPlatformAuthCode = SM2Utils.encryptByKeyStr(platformAuthCode, clientKey);
            String encryAuthorizationCode = SM2Utils.encryptByKeyStr(line.getAuthorizationCode(), clientKey);
            String encryRegisterCode = SM2Utils.encryptByKeyStr(line.getRegisterNumber(), clientKey);

            //搭建服务
            WSExtendRegisterServiceService service = new WSExtendRegisterServiceService();
            WSExtendRegisterService extend = service.getWSExtendRegisterServicePort();

            //插入接口日志表
            hlsWsRequests = createRequestLog("https://ws.zhongdengwang.org.cn/mfrs_ws_test/services/ExtendRegisterService?wsdl", xmlFileContent, line.getLineId());

            //获取数据
            byte[] resBytes = extend.extendRegister(line.getTypebz().getBytes(), encryPlatformAuthCode.getBytes(),
                    encryLoginToken.getBytes(), encryRegisterCode.getBytes(), encryAuthorizationCode.getBytes(),
                    attachmentDto.getFileName().getBytes(), encryXmlFileContent.getBytes(),
                    ClientUtils.getAttachmentZip(attachmentZipPath));

            String resData = new String(resBytes);
            setResData(resultJson, hlsWsRequests, resData);
        }
        catch (Exception e){
            e.printStackTrace();
            setErrData(resultJson, hlsWsRequests, e);
        }

        //返回结果 给数据库和前端
        hlsWsRequestsMapper.updateByPrimaryKeySelective(hlsWsRequests);
        return resultJson;
    }

    public JSONObject registerTerminate(String platformAuthCode, String loginToken, String xmlFileContent, FndZhongDengLines line, FndAtmAttachmentDto attachmentDto){
        JSONObject resultJson = new JSONObject();
        HlsWsRequests hlsWsRequests = new HlsWsRequests();

        try {
            /*SM2算法加密*/
            String encryLoginToken = SM2Utils.encryptByKeyStr(loginToken, clientKey);
            String encryXmlFileContent = SM2Utils.encryptByKeyStr(xmlFileContent, clientKey);
            String encryPlatformAuthCode = SM2Utils.encryptByKeyStr(platformAuthCode, clientKey);
            String encryAuthorizationCode = SM2Utils.encryptByKeyStr(line.getAuthorizationCode(), clientKey);
            String encryRegisterCode = SM2Utils.encryptByKeyStr(line.getRegisterNumber(), clientKey);

            //搭建服务
            WSTerminateRegisterServiceService service = new WSTerminateRegisterServiceService();
            WSTerminateRegisterService terminate = service.getWSTerminateRegisterServicePort();

            //插入接口日志表
            hlsWsRequests = createRequestLog("https://ws.zhongdengwang.org.cn/mfrs_ws_test/services/TerminateRegisterService?wsdl", xmlFileContent, line.getLineId());

            //获取数据
            byte[] resBytes = terminate.terminateRegister(line.getTypebz().getBytes(), encryPlatformAuthCode.getBytes(),
                    encryLoginToken.getBytes(), encryRegisterCode.getBytes(), encryAuthorizationCode.getBytes(),
                    attachmentDto.getFileName().getBytes(), encryXmlFileContent.getBytes());

            String resData = new String(resBytes);
            setResData(resultJson, hlsWsRequests, resData);
        }
        catch (Exception e){
            e.printStackTrace();
            setErrData(resultJson, hlsWsRequests, e);
        }

        //返回结果 给数据库和前端
        hlsWsRequestsMapper.updateByPrimaryKeySelective(hlsWsRequests);
        return resultJson;
    }


    /***
     * 融资租赁-登记入口方法;
     * @param
     * @param
     ***/
    public void registerThread(IRequest request, List<FndZhongDengBatch> fndZhongDengBatches, String loginToken) {
        JSONObject resultJson = new JSONObject();
        List<FndZhongDengLines> fndZhongDengLinesList = new ArrayList<>();
        /*根据传入ids循环上报中登网*/
        synchronized (lock) {
            for (FndZhongDengBatch batch : fndZhongDengBatches) {
                FndZhongDengLines fndZhongDengLines = new FndZhongDengLines();
                fndZhongDengLines.setLineId(batch.getLineId());
                fndZhongDengLines = fndZhongDengLinesMapper.selectByPrimaryKey(fndZhongDengLines);

                if (Objects.nonNull(fndZhongDengLines) && "UPING".equalsIgnoreCase(fndZhongDengLines.getUpStatus())) {
                    try {

                        String xmlFileContent = "";
                        String attachmentZipPath = "";

                        FndAtmAttachmentDto fndAtmAttachmentDto = new FndAtmAttachmentDto();
                        fndAtmAttachmentDto.setAttachmentId(fndZhongDengLines.getAttachmentXmlId());
                        fndAtmAttachmentDto = fndAtmAttachmentMapper.selectByPrimaryKey(fndAtmAttachmentDto);

                        /*解析xml文件内容*/
                        xmlFileContent = new String(Objects.requireNonNull(ClientUtils.getxmlFileContent(fndAtmAttachmentDto.getFilePath())));

                        /*插入接口日志表*/
                        if ("INIT".equalsIgnoreCase(fndZhongDengLines.getUpStage())) {
                            resultJson = registerInit(fndZhongDengLines.getTypebz(), platformAuthCode, loginToken, fndAtmAttachmentDto.getFileName(), xmlFileContent, fndZhongDengLines.getLineId());
                        }
                        else if("AMEND".equalsIgnoreCase(fndZhongDengLines.getUpStage())){
                            resultJson = registerAmend(platformAuthCode, loginToken, xmlFileContent, attachmentZipPath, fndZhongDengLines, fndAtmAttachmentDto);
                        }
                        else if("EXTEND".equalsIgnoreCase(fndZhongDengLines.getUpStage())){
                            resultJson = registerExtend(platformAuthCode, loginToken, xmlFileContent, attachmentZipPath, fndZhongDengLines, fndAtmAttachmentDto);
                        }
                        else if("TERMINATE".equalsIgnoreCase(fndZhongDengLines.getUpStage())){
                            resultJson = registerTerminate(platformAuthCode, loginToken, xmlFileContent, fndZhongDengLines, fndAtmAttachmentDto);
                        }

                        String returns = "";
                        if ("0".equalsIgnoreCase(resultJson.getString("code"))) {
                            returns = resultJson.getString("info");
                        } else {
                            returns = "<feedback>\n<registertype>LR</registertype>\n<registerresult>001</registerresult>\n<registernumber>I0000001</registernumber>\n<authorizationcode>A0000001</authorizationcode>\n<errors>\n<error>\n" + resultJson.getString("info") + "</error>\n</errors>\n</feedback>\n";
                        }
                        System.out.println("dddd" + new String(returns));

                        /*解析接口返回结果*/
                        org.json.JSONObject returnJson;
                        returnJson = XML.toJSONObject(returns);
                        String registerResult = "";
                        String registerNumber = "";
                        String authorizationCode = "";
                        String error = "";
                        registerResult = returnJson.getJSONObject("feedback").getString("registerresult");
                        registerNumber = returnJson.getJSONObject("feedback").getString("registernumber");
                        authorizationCode = returnJson.getJSONObject("feedback").getString("authorizationcode");

                        /*成功*/
                        if (Objects.nonNull(registerResult) && "001".equalsIgnoreCase(registerResult)) {
                            fndZhongDengLines.setRegisterNumber(registerNumber);
                            fndZhongDengLines.setAuthorizationCode(authorizationCode);
                            fndZhongDengLines.setUpStatus("SUCCESS");
                            fndZhongDengLines.setReturnMsg("上报成功");
                            /*失败*/
                        } else {
                            error = returnJson.getJSONObject("feedback").getString("errors");
                            fndZhongDengLines.setUpStatus("FAIL");
                            fndZhongDengLines.setReturnMsg(error);
                        }

                        fndZhongDengLines.setUpDate(new Date());
                        fndZhongDengLines.set__status(DTOStatus.UPDATE);
                    } catch (RuntimeException e) {
                        e.printStackTrace();
                    } catch (Exception e) {
                        // TODO Auto-generated catch block
                        e.printStackTrace();
                        fndZhongDengLines.setUpStatus("FAIL");
                        fndZhongDengLines.setReturnMsg(e.getMessage());
                    }
                    fndZhongDengLinesList.add(fndZhongDengLines);
                }
            }

            if (fndZhongDengLinesList.size() > 0) {
                fndZhongDengLinesService.batchUpdate(request, fndZhongDengLinesList);
            }
        }
    }

    /***
     * 融资租赁-登记入口方法;
     * @param request
     * @param batchId
     ***/
    @Override
    public JSONObject initRegisterService(IRequest request, Long batchId) {
        JSONObject resultJson = new JSONObject();

        /*根据批次ID获取所有上报请求id*/
        List<FndZhongDengBatch> fndZhongDengBatches = new ArrayList<>();
        FndZhongDengBatch fndZhongDengBatch = new FndZhongDengBatch();
        fndZhongDengBatch.setBatchId(batchId);
        fndZhongDengBatches = fndZhongDengBatchMapper.select(fndZhongDengBatch);


        if (fndZhongDengBatches.size() == 0) {
            resultJson.put("code", "000");
            resultJson.put("info", "000");
            return resultJson;
        }

        /*获取中登网登录loginToken*/
        loginToken = getRegisterToken();
        /*返回结果loginToken解析，如果返回异常退出当前请求*/
        if (loginToken.contains("Error")) {
            String errorCode = "-1";
            String errorInfo = "-1";
            if (errorCode.contains(":")) {
                errorCode = loginToken.split(":")[1];
                if (errorCode.contains("_")) {
                    errorCode = loginToken.split("_")[0];
                    errorInfo = loginToken.split("_")[1];
                }
            }

            resultJson.put("code", errorCode);
            resultJson.put("info", errorInfo);
        } else {

            final List<FndZhongDengBatch> fndZhongDengBatchList = fndZhongDengBatches;

            /*启用新线程进行异步处理中登网接口请求*/
            ExecutorService cachedThreadPool = Executors.newCachedThreadPool();
            cachedThreadPool.execute(new Runnable() {
                @Override
                public void run() {
                    // d
                    try {
                        registerThread(request, fndZhongDengBatchList, loginToken);
                    } catch (Exception e) {
                        // TODO Auto-generated catch block
                        e.printStackTrace();
                    }
                }
            });
            /*关闭线程*/
            cachedThreadPool.shutdown();
//            List<FndZhongDengLines> fndZhongDengLinesList = new ArrayList<>();
//            /*根据传入ids循环上报中登网*/
//            for (FndZhongDengBatch batch : fndZhongDengBatches) {
//
//                FndZhongDengLines fndZhongDengLines = new FndZhongDengLines();
//                fndZhongDengLines.setLineId(batch.getLineId());
//                fndZhongDengLines = fndZhongDengLinesMapper.selectByPrimaryKey(fndZhongDengLines);
//
//                if (Objects.nonNull(fndZhongDengLines) && "UPING".equalsIgnoreCase(fndZhongDengLines.getUpStatus())) {
//                    String xmlFileContent = "";
//                    String attachmentZipPath = "";
//                    try {
//                        String registerResult = "";
//                        String registerNumber = "";
//                        String authorizationCode = "";
//                        String error = "";
//                        org.json.JSONObject returnJson;
//
//                        FndAtmAttachmentDto fndAtmAttachmentDto = new FndAtmAttachmentDto();
//                        fndAtmAttachmentDto.setAttachmentId(fndZhongDengLines.getAttachmentXmlId());
//                        fndAtmAttachmentDto = fndAtmAttachmentMapper.selectByPrimaryKey(fndAtmAttachmentDto);
//
//                        /*解析xml文件内容*/
//                        xmlFileContent = new String(ClientUtils.getxmlFileContent(fndAtmAttachmentDto.getFilePath()));
//
//                        /*插入接口日志表*/
//                        if ("INIT".equalsIgnoreCase(fndZhongDengLines.getUpStage())) {
//                            resultJson = registerInit(fndZhongDengLines.getTypebz(), platformAuthCode, loginToken, fndAtmAttachmentDto.getFileName(), xmlFileContent, fndZhongDengLines.getLineId());
//                        }
//                        String returns = "";
//                        if ("0".equalsIgnoreCase(resultJson.getString("code"))) {
//                            returns = resultJson.getString("info");
//                        } else {
//                            returns = "<feedback>\n<registertype>LR</registertype>\n<registerresult>001</registerresult>\n<registernumber>I0000001</registernumber>\n<authorizationcode>A0000001</authorizationcode>\n<errors>\n<error>\n" + resultJson.getString("info") + "</error>\n</errors>\n</feedback>\n";
//                        }
//
//                        /*解析接口返回结果*/
//                        returnJson = XML.toJSONObject(returns);
//                        registerResult = returnJson.getJSONObject("feedback").getString("registerresult");
//                        registerNumber = returnJson.getJSONObject("feedback").getString("registernumber");
//                        authorizationCode = returnJson.getJSONObject("feedback").getString("authorizationcode");
//
//                        /*成功*/
//                        if (Objects.nonNull(registerResult) && "001".equalsIgnoreCase(registerResult)) {
//                            fndZhongDengLines.setRegisterNumber(registerNumber);
//                            fndZhongDengLines.setAuthorizationCode(authorizationCode);
//                            fndZhongDengLines.setUpStatus("SUCCESS");
//                            fndZhongDengLines.setReturnMsg("上报成功");
//                            /*失败*/
//                        } else {
//                            error = returnJson.getJSONObject("feedback").getString("errors");
//                            fndZhongDengLines.setUpStatus("FAIL");
//                            fndZhongDengLines.setReturnMsg(error);
//                        }
//
//                        fndZhongDengLines.setUpDate(new Date());
//                        fndZhongDengLines.set__status(DTOStatus.UPDATE);
//
//                        System.out.println("dddd" + new String(returns));
//                    } catch (Exception e) {
//                        // TODO Auto-generated catch block
//                        e.printStackTrace();
//                        fndZhongDengLines.setUpStatus("FAIL");
//                        fndZhongDengLines.setReturnMsg(e.getMessage());
//                    }
//
//                    fndZhongDengLinesList.add(fndZhongDengLines);
//                }
//
//            }
//
//            if (fndZhongDengLinesList.size() > 0) {
//                fndZhongDengLinesService.batchUpdate(request, fndZhongDengLinesList);
//            }

            resultJson.put("code", "000");
            resultJson.put("info", "000");
        }
        return resultJson;
    }





}